#
# spec file for package mcpp
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mcpp
Version:        2.7.2
Release:        24.18
Summary:        Matsui's C Preprocessor
License:        BSD-3-Clause
Group:          Development/Languages/C and C++
URL:            http://mcpp.sourceforge.net/
Source0:        http://sourceforge.net/projects/mcpp/files/mcpp/V.%{version}/%{name}-%{version}.tar.gz
Patch0:         %{name}-%{version}.diff
Patch1:         CVE-2019-14274.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
mcpp is a small and portable C/C++ preprocessor implementing all of
C90, C99 and C++98.

%define _libname libmcpp0

%package -n %{_libname}
Summary:        The shared library of Matsui's C Preprocessor
Group:          Development/Libraries/C and C++

%description -n %{_libname}
mcpp is a small and portable C/C++ preprocessor implementing all of
C90, C99 and C++98.

This package holds the shared libraries of libev.

%package devel
Summary:        Development files for mcpp
Group:          Development/Libraries/C and C++
Requires:       %{_libname} = %{version}
Requires:       %{name} = %{version}

%description devel
mcpp is a small and portable C/C++ preprocessor implementing all of
C90, C99 and C++98.

This package holds the development files for libev.

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
export CFLAGS="%{optflags} -D_BSD_SOURCE"
%configure --enable-mcpplib
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
rm -rf %{buildroot}%{_datadir}/doc/mcpp
rm -rf %{buildroot}%{_libdir}/libmcpp.*a

%post   -n %{_libname} -p /sbin/ldconfig

%postun -n %{_libname} -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc doc/mcpp-manual.html LICENSE NEWS README
%{_bindir}/*
%{_mandir}/man1/mcpp.1.gz

%files -n %{_libname}
%defattr(-,root,root,-)
%{_libdir}/libmcpp.so.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/mcpp_*.h
%{_libdir}/libmcpp.so

%changelog
* Wed Mar 18 2020 Dirk Mueller <dmueller@suse.com>
- add CVE-2019-14274.patch (bsc#1143032, CVE-2019-14274)
* Tue May  5 2015 mpluskal@suse.com
- Use url for source
- Cleanup spec file with spec-cleaner
* Thu Oct 18 2012 mrueckert@suse.de
-  enable building of the shared library
* Thu Mar 12 2009 dmueller@suse.de
- update to 2.7.2:
  * Enabled some CPU-specific predefined macros in compiler-
    independent-build as well as compiler-specific-build, because
    there are some occasions which require those macros when we use
    some compiler system's header files.  Created init_cpu_macro().
    (configure.ac, noconfig.H, configed.H, main.c, system.c)
  * Enabled -m32 and -m64 options even on 32-bits systems and on
    compiler-independent-build, when the OS is UNIX-like one.  These
    options change some predefined macros.  (system.c)
  * Made -z option to output #include lines themselves.  (system.c)
  * Fixed a bug of source line numbering in library-build.  (by
    Dwayne Boone) (main.c)
  * V.2.7.1
  * Fixed a bug of newline synchronization on -K option.  Created
    sync_linenum().  (Thanks to Benjamin Smedberg) (directive.c)
  * Made GCC-specific-build on x86_64 and ppc64 have two sets of
    predefines for 32bit mode and 64bit mode, and implemented -m32
    and -m64 options.  (Thanks to Benjamin Smedberg) (configure.ac,
    set_mcpp.sh, system.c)
  * Stopped to use freopen() so that a main program which links
    libmcpp can use stdin, stdout and stderr.  (by Benoit Foucher)
    (main.c)
  * Fixed a bug of file-handle leak on -MD and -MF options.
    (Thanks to Masashi Fujita) (system.c)
  * Added ports to Vicual C++ 6.0 and Borland C++ 5.9 (aka C++
    Builder 2007).  (by Dwayne Boone) (vc6.dif, bc59.dif, eval.c)
  * Revised declaration of stpcpy().  (internal.H)
  * Created macro notification mode, implemented -K option and '#
    pragma MCPP debug macro_call' sub-directive to enable this mode
    on STD mode.  Created get_src_location(), print_macro_inf(),
    print_macro_arg(), close_macro_inf(), chk_magic_balance(),
    remove_magics(), some MAC_* macros to define magic characters,
    struct LINE_COL, MACRO_INF.  Revised many functions.
* Mon Jun 18 2007 dmueller@suse.de
- Initial package (2.6.4)
